@@ -1,22 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,6 +26,9 @@
  */
 
 #include "WP42Parser.h"
+
+#include <memory>
+
 #include "WP42Part.h"
 #include "WPXHeader.h"
 #include "libwpd_internal.h"
@@ -34,8 +37,8 @@
 #include "WP42StylesListener.h"
 #include "WP42ContentListener.h"
 
-WP42Parser::WP42Parser(WPXInputStream *input, WPXEncryption *encryption) :
-	WPXParser(input, 0, encryption)
+WP42Parser::WP42Parser(librevenge::RVNGInputStream *input, WPXEncryption *encryption) :
+	WPXParser(input, nullptr, encryption)
 {
 }
 
@@ -43,11 +46,11 @@ WP42Parser::~WP42Parser()
 {
 }
 
-void WP42Parser::parse(WPXInputStream *input, WPXEncryption *encryption, WP42Listener *listener)
+void WP42Parser::parse(librevenge::RVNGInputStream *input, WPXEncryption *encryption, WP42Listener *listener)
 {
 	listener->startDocument();
 
-	input->seek(0, WPX_SEEK_SET);
+	input->seek(0, librevenge::RVNG_SEEK_SET);
 
 	WPD_DEBUG_MSG(("WordPerfect: Starting document body parse (position = %ld)\n",(long)input->tell()));
 
@@ -57,14 +60,14 @@ void WP42Parser::parse(WPXInputStream *input, WPXEncryption *encryption, WP42Lis
 }
 
 // parseDocument: parses a document body (may call itself recursively, on other streams, or itself)
-void WP42Parser::parseDocument(WPXInputStream *input, WPXEncryption *encryption, WP42Listener *listener)
+void WP42Parser::parseDocument(librevenge::RVNGInputStream *input, WPXEncryption *encryption, WP42Listener *listener)
 {
-	while (!input->atEOS())
+	while (!input->isEnd())
 	{
-		uint8_t readVal;
+		unsigned char readVal;
 		readVal = readU8(input, encryption);
 
-		if (readVal < (uint8_t)0x20)
+		if (readVal < (unsigned char)0x20)
 		{
 			WPD_DEBUG_MSG(("Offset: %i, Handling Control Character 0x%2x\n", (unsigned int)input->tell(), readVal));
 
@@ -90,14 +93,14 @@ void WP42Parser::parseDocument(WPXInputStream *input, WPXEncryption *encryption,
 				break;
 			}
 		}
-		else if (readVal >= (uint8_t)0x20 && readVal <= (uint8_t)0x7F)
+		else if (readVal >= (unsigned char)0x20 && readVal <= (unsigned char)0x7F)
 		{
 			WPD_DEBUG_MSG(("Offset: %i, Handling Ascii Character 0x%2x\n", (unsigned int)input->tell(), readVal));
 
 			// normal ASCII characters
-			listener->insertCharacter( readVal );
+			listener->insertCharacter(readVal);
 		}
-		else if (readVal >= (uint8_t)0x80 && readVal <= (uint8_t)0xBF)
+		else if (readVal >= (unsigned char)0x80 && readVal <= (unsigned char)0xBF)
 		{
 			WPD_DEBUG_MSG(("Offset: %i, Handling Single Character Function 0x%2x\n", (unsigned int)input->tell(), readVal));
 
@@ -149,23 +152,20 @@ void WP42Parser::parseDocument(WPXInputStream *input, WPXEncryption *encryption,
 				break;
 			}
 		}
-		else if (readVal >= (uint8_t)0xC0 && readVal <= (uint8_t)0xFE)
+		else if (readVal >= (unsigned char)0xC0 && readVal <= (unsigned char)0xFE)
 		{
-			WP42Part *part = WP42Part::constructPart(input, encryption, readVal);
+			std::unique_ptr<WP42Part> part(WP42Part::constructPart(input, encryption, readVal));
 			if (part)
-			{
 				part->parse(listener);
-				DELETEP(part);
-			}
 		}
 		// ignore the rest since they are not documented and at least 0xFF is a special character that
 		// marks end of variable length part in variable length multi-byte functions
 	}
 }
 
-void WP42Parser::parse(WPXDocumentInterface *documentInterface)
+void WP42Parser::parse(librevenge::RVNGTextInterface *documentInterface)
 {
-	WPXInputStream *input = getInput();
+	librevenge::RVNGInputStream *input = getInput();
 	WPXEncryption *encryption = getEncryption();
 	std::list<WPXPageSpan> pageList;
 	std::vector<WP42SubDocument *> subDocuments;
@@ -189,7 +189,7 @@ void WP42Parser::parse(WPXDocumentInterface *documentInterface)
 			else
 			{
 				previousPage = Iter;
-				Iter++;
+				++Iter;
 			}
 		}
 
@@ -199,20 +199,20 @@ void WP42Parser::parse(WPXDocumentInterface *documentInterface)
 		parse(input, encryption, &listener);
 
 		// cleanup section: free the used resources
-		for (std::vector<WP42SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); iterSubDoc++)
+		for (auto &subDocument : subDocuments)
 		{
-			if (*iterSubDoc)
-				delete (*iterSubDoc);
+			if (subDocument)
+				delete subDocument;
 		}
 	}
-	catch(FileException)
+	catch (FileException)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: File Exception. Parse terminated prematurely."));
 
-		for (std::vector<WP42SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); iterSubDoc++)
+		for (auto &subDocument : subDocuments)
 		{
-			if (*iterSubDoc)
-				delete (*iterSubDoc);
+			if (subDocument)
+				delete subDocument;
 		}
 
 		throw FileException();
@@ -220,34 +220,34 @@ void WP42Parser::parse(WPXDocumentInterface *documentInterface)
 
 }
 
-void WP42Parser::parseSubDocument(WPXDocumentInterface *documentInterface)
+void WP42Parser::parseSubDocument(librevenge::RVNGTextInterface *documentInterface)
 {
 	std::list<WPXPageSpan> pageList;
 	std::vector<WP42SubDocument *> subDocuments;
 
-	WPXInputStream *input = getInput();
+	librevenge::RVNGInputStream *input = getInput();
 
 	try
 	{
 		WP42StylesListener stylesListener(pageList, subDocuments);
 		stylesListener.startSubDocument();
-		parseDocument(input, 0, &stylesListener);
+		parseDocument(input, nullptr, &stylesListener);
 		stylesListener.endSubDocument();
 
 		WP42ContentListener listener(pageList, subDocuments, documentInterface);
 		listener.startSubDocument();
-		parseDocument(input, 0, &listener);
+		parseDocument(input, nullptr, &listener);
 		listener.endSubDocument();
-		for (std::vector<WP42SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); iterSubDoc++)
-			if (*iterSubDoc)
-				delete (*iterSubDoc);
+		for (auto &subDocument : subDocuments)
+			if (subDocument)
+				delete subDocument;
 	}
-	catch(FileException)
+	catch (FileException)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: File Exception. Parse terminated prematurely."));
-		for (std::vector<WP42SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); iterSubDoc++)
-			if (*iterSubDoc)
-				delete (*iterSubDoc);
+		for (auto &subDocument : subDocuments)
+			if (subDocument)
+				delete subDocument;
 		throw FileException();
 	}
 }
