@@ -36,8 +36,8 @@ class WP5FontNameStringPoolPacket : public WP5GeneralPacketData
 {
 public:
 	WP5FontNameStringPoolPacket(librevenge::RVNGInputStream *input, WPXEncryption *encryption, int id, unsigned dataOffset, unsigned dataSize);
-	~WP5FontNameStringPoolPacket();
-	void _readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned dataSize);
+	~WP5FontNameStringPoolPacket() override;
+	void _readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned dataSize) override;
 	librevenge::RVNGString getFontName(const unsigned int offset) const;
 
 private:
