@@ -1,22 +1,23 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
  * Copyright (C) 2007 Novell, Inc. (http://www.novell.com)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -30,11 +31,11 @@
 #include "WP5Listener.h"
 #include "WPXFileStructure.h"
 
-WP5PageFormatGroup::WP5PageFormatGroup(WPXInputStream *input) :
+WP5PageFormatGroup::WP5PageFormatGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption) :
 	WP5VariableLengthGroup(),
 	m_leftMargin(0),
 	m_rightMargin(0),
-	m_lineSpacing(1.0f),
+	m_lineSpacing(1.0),
 	m_tabStops(),
 	m_marginOffset(0xffff),
 	m_topMargin(0),
@@ -45,14 +46,14 @@ WP5PageFormatGroup::WP5PageFormatGroup(WPXInputStream *input) :
 	m_formWidth(0),
 	m_formOrientation(PORTRAIT)
 {
-	_read(input);
+	_read(input, encryption);
 }
 
 WP5PageFormatGroup::~WP5PageFormatGroup()
 {
 }
 
-void WP5PageFormatGroup::_readContents(WPXInputStream *input)
+void WP5PageFormatGroup::_readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption)
 {
 	// this group can contain different kinds of data, thus we need to read
 	// the contents accordingly
@@ -60,42 +61,42 @@ void WP5PageFormatGroup::_readContents(WPXInputStream *input)
 	{
 	case WP5_TOP_PAGE_FORMAT_GROUP_LEFT_RIGHT_MARGIN_SET:
 		// skip 4 bytes (old values of no interest for us)
-		input->seek(4, WPX_SEEK_CUR);
-		m_leftMargin = readU16(input);
-		m_rightMargin = readU16(input);
+		input->seek(4, librevenge::RVNG_SEEK_CUR);
+		m_leftMargin = readU16(input, encryption);
+		m_rightMargin = readU16(input, encryption);
 		WPD_DEBUG_MSG(("WordPerfect: Page format group left/right margin set (left margin: %i, right margin: %i)\n", m_leftMargin, m_rightMargin));
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_SPACING_SET:
 		// skip 2 bytes (old spacing of no interest for us)
-		input->seek(2, WPX_SEEK_CUR);
+		input->seek(2, librevenge::RVNG_SEEK_CUR);
 		{
-			uint16_t lineSpacing = readU16(input);
-			int8_t lineSpacingIntegerPart = (int8_t)((lineSpacing & 0xFF00) >> 8);
-			float lineSpacingFractionalPart = (float)(lineSpacing & 0x00FF)/(float)0xFF;
+			unsigned short lineSpacing = readU16(input, encryption);
+			signed char lineSpacingIntegerPart = (signed char)((lineSpacing & 0xFF00) >> 8);
+			double lineSpacingFractionalPart = (double)(lineSpacing & 0x00FF)/(double)0xFF;
 			WPD_DEBUG_MSG(("WordPerfect: Page format group line spacing - integer part: %i fractional part: %f (original value: %i)\n",
-				       lineSpacingIntegerPart, lineSpacingFractionalPart, lineSpacing));
+			               lineSpacingIntegerPart, lineSpacingFractionalPart, lineSpacing));
 			m_lineSpacing = lineSpacingIntegerPart + lineSpacingFractionalPart;
 		}
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_TAB_SET:
-		input->seek(100, WPX_SEEK_CUR);
+		input->seek(100, librevenge::RVNG_SEEK_CUR);
 		m_tabStops.reserve(40);
 		{
 
-			uint16_t tmpTabPosition = 0;
-			for (unsigned i=0; i < 40 && (tmpTabPosition = readU16(input)) != 0xFFFF; i++)
+			unsigned short tmpTabPosition = 0;
+			for (unsigned i=0; i < 40 && (tmpTabPosition = readU16(input, encryption)) != 0xFFFF; i++)
 			{
 				m_tabStops.push_back(WPXTabStop());
-				m_tabStops[i].m_position = (float)((double)tmpTabPosition/(double)WPX_NUM_WPUS_PER_INCH);
+				m_tabStops[i].m_position = (double)((double)tmpTabPosition/(double)WPX_NUM_WPUS_PER_INCH);
 			}
 			if ((tmpTabPosition & 0xFFFF) == 0xFFFF)
-				input->seek((39 - m_tabStops.size()) * 2, WPX_SEEK_CUR);
+				input->seek((39 - (long)m_tabStops.size()) * 2, librevenge::RVNG_SEEK_CUR);
 			else
-				input->seek((40 - m_tabStops.size()) * 2, WPX_SEEK_CUR);
+				input->seek((40 - (long)m_tabStops.size()) * 2, librevenge::RVNG_SEEK_CUR);
 
 			for (unsigned j=0; (j < (m_tabStops.size() / 2) + (m_tabStops.size() % 2)) && (j < 20); j++)
 			{
-				uint8_t tmpTabType = readU8(input);
+				unsigned char tmpTabType = readU8(input, encryption);
 				if (j*2 < m_tabStops.size())
 				{
 					switch ((tmpTabType & 0x30) >> 4)
@@ -149,16 +150,16 @@ void WP5PageFormatGroup::_readContents(WPXInputStream *input)
 					}
 				}
 			}
-			input->seek(20 - (m_tabStops.size() / 2 ) - (m_tabStops.size() % 2), WPX_SEEK_CUR);
-			
+			input->seek(20 - long(m_tabStops.size() / 2) - long(m_tabStops.size() % 2), librevenge::RVNG_SEEK_CUR);
+
 			if ((getSize() > 4) && (getSize() - 4 == 0x00D0))
 			{
-				input->seek(2, WPX_SEEK_CUR);
-				m_marginOffset = readU16(input);
+				input->seek(2, librevenge::RVNG_SEEK_CUR);
+				m_marginOffset = readU16(input, encryption);
 				if (0xFFFF != (m_marginOffset & 0xFFFF))
 				{
-					for (std::vector<WPXTabStop>::iterator iter = m_tabStops.begin(); iter != m_tabStops.end(); iter++)
-						iter->m_position -= (double)m_marginOffset/(double)WPX_NUM_WPUS_PER_INCH;
+					for (auto &tabStop : m_tabStops)
+						tabStop.m_position -= (double)((double)m_marginOffset/(double)WPX_NUM_WPUS_PER_INCH);
 				}
 			}
 			else
@@ -167,15 +168,15 @@ void WP5PageFormatGroup::_readContents(WPXInputStream *input)
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_TOP_BOTTOM_MARGIN_SET:
 		// skip 4 bytes (old values of no interest for us)
-		input->seek(4, WPX_SEEK_CUR);
-		m_topMargin = readU16(input);
-		m_bottomMargin = readU16(input);
+		input->seek(4, librevenge::RVNG_SEEK_CUR);
+		m_topMargin = readU16(input, encryption);
+		m_bottomMargin = readU16(input, encryption);
 		WPD_DEBUG_MSG(("WordPerfect: Page format group top/bottom margin set (top margin: %i, bottom margin: %i)\n", m_topMargin, m_bottomMargin));
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_JUSTIFICATION:
 		// skip 1 byte (old justification of no interest for us)
-		input->seek(1, WPX_SEEK_CUR);
-		m_justification = readU8(input);
+		input->seek(1, librevenge::RVNG_SEEK_CUR);
+		m_justification = readU8(input, encryption);
 		// WP6 and WP3 have one more category of justification
 		// Following hack allows us to use the same function for the three parsers
 		if (m_justification == 0x04)
@@ -184,18 +185,18 @@ void WP5PageFormatGroup::_readContents(WPXInputStream *input)
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_SUPPRESS_PAGE_CHARACTERISTICS:
 		// skip 1 byte (old suppress code)
-		input->seek(1, WPX_SEEK_CUR);
-		m_suppressCode = readU8(input);
+		input->seek(1, librevenge::RVNG_SEEK_CUR);
+		m_suppressCode = readU8(input, encryption);
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_FORM:
-		uint8_t tmpOrientation;
+		unsigned char tmpOrientation;
 		// skip to the new DESIRED values (99 - 4)
-		input->seek(95, WPX_SEEK_CUR);
-		m_formLength = readU16(input); // New DESIRED length
-		m_formWidth = readU16(input); // New DESIRED width
+		input->seek(95, librevenge::RVNG_SEEK_CUR);
+		m_formLength = readU16(input, encryption); // New DESIRED length
+		m_formWidth = readU16(input, encryption); // New DESIRED width
 		// skipp to the orientation value (193 - 103)
-		input->seek(90, WPX_SEEK_CUR);
-		tmpOrientation = readU8(input); // New EFFECTIVE orientation
+		input->seek(90, librevenge::RVNG_SEEK_CUR);
+		tmpOrientation = readU8(input, encryption); // New EFFECTIVE orientation
 		switch (tmpOrientation)
 		{
 		case 0x01:
@@ -209,7 +210,7 @@ void WP5PageFormatGroup::_readContents(WPXInputStream *input)
 			break;
 		}
 		WPD_DEBUG_MSG(("WordPerfect: Read form information (length: %i), (width: %i), (form orientation: %s),\n",
-				m_formLength, m_formWidth, ((m_formOrientation==PORTRAIT)?"portrait":"landscape")));
+		               m_formLength, m_formWidth, ((m_formOrientation==PORTRAIT)?"portrait":"landscape")));
 		break;
 	default: /* something else we don't support, since it isn't in the docs */
 		break;
@@ -227,11 +228,11 @@ void WP5PageFormatGroup::parse(WP5Listener *listener)
 		listener->marginChange(WPX_RIGHT, m_rightMargin);
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_SPACING_SET:
-	        WPD_DEBUG_MSG(("WordPerfect: parsing a line spacing change of: %f\n", m_lineSpacing));
-	        listener->lineSpacingChange(m_lineSpacing);
+		WPD_DEBUG_MSG(("WordPerfect: parsing a line spacing change of: %f\n", m_lineSpacing));
+		listener->lineSpacingChange(m_lineSpacing);
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_TAB_SET:
-	        WPD_DEBUG_MSG(("WordPerfect: parsing a tab set\n"));
+		WPD_DEBUG_MSG(("WordPerfect: parsing a tab set\n"));
 		listener->setTabs(m_tabStops, m_marginOffset);
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_TOP_BOTTOM_MARGIN_SET:
@@ -251,3 +252,4 @@ void WP5PageFormatGroup::parse(WP5Listener *listener)
 		break;
 	}
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
