@@ -26,6 +26,9 @@
  */
 
 #include "WP5Parser.h"
+
+#include <memory>
+
 #include "WPXHeader.h"
 #include "WP5Part.h"
 #include "WP5ContentListener.h"
@@ -47,17 +50,7 @@ WP5Parser::~WP5Parser()
 
 WP5PrefixData *WP5Parser::getPrefixData(librevenge::RVNGInputStream *input, WPXEncryption *encryption)
 {
-	WP5PrefixData *prefixData = 0;
-	try
-	{
-		prefixData = new WP5PrefixData(input, encryption);
-		return prefixData;
-	}
-	catch (FileException)
-	{
-		DELETEP(prefixData);
-		throw FileException();
-	}
+	return new WP5PrefixData(input, encryption);
 }
 
 void WP5Parser::parse(librevenge::RVNGInputStream *input, WPXEncryption *encryption, WP5Listener *listener)
@@ -115,12 +108,9 @@ void WP5Parser::parseDocument(librevenge::RVNGInputStream *input, WPXEncryption
 		}
 		else
 		{
-			WP5Part *part = WP5Part::constructPart(input, encryption, readVal);
+			std::unique_ptr<WP5Part> part(WP5Part::constructPart(input, encryption, readVal));
 			if (part)
-			{
 				part->parse(listener);
-				DELETEP(part);
-			}
 		}
 	}
 }
@@ -131,7 +121,7 @@ void WP5Parser::parse(librevenge::RVNGTextInterface *documentInterface)
 	WPXEncryption *encryption = getEncryption();
 	std::list<WPXPageSpan> pageList;
 	WPXTableList tableList;
-	WP5PrefixData *prefixData = 0;
+	WP5PrefixData *prefixData = nullptr;
 	std::vector<WP5SubDocument *> subDocuments;
 
 	try
@@ -198,10 +188,10 @@ void WP5Parser::parse(librevenge::RVNGTextInterface *documentInterface)
 
 		// cleanup section: free the used resources
 		delete prefixData;
-		for (std::vector<WP5SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); ++iterSubDoc)
+		for (auto &subDocument : subDocuments)
 		{
-			if (*iterSubDoc)
-				delete(*iterSubDoc);
+			if (subDocument)
+				delete subDocument;
 		}
 	}
 	catch (FileException)
@@ -209,10 +199,10 @@ void WP5Parser::parse(librevenge::RVNGTextInterface *documentInterface)
 		WPD_DEBUG_MSG(("WordPerfect: File Exception. Parse terminated prematurely."));
 
 		delete prefixData;
-		for (std::vector<WP5SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); ++iterSubDoc)
+		for (auto &subDocument : subDocuments)
 		{
-			if (*iterSubDoc)
-				delete(*iterSubDoc);
+			if (subDocument)
+				delete subDocument;
 		}
 
 		throw FileException();
@@ -231,26 +221,26 @@ void WP5Parser::parseSubDocument(librevenge::RVNGTextInterface *documentInterfac
 	{
 		WP5StylesListener stylesListener(pageList, tableList, subDocuments);
 		stylesListener.startSubDocument();
-		parseDocument(input, 0, &stylesListener);
+		parseDocument(input, nullptr, &stylesListener);
 		stylesListener.endSubDocument();
 
 		input->seek(0, librevenge::RVNG_SEEK_SET);
 
 		WP5ContentListener listener(pageList, subDocuments, documentInterface);
 		listener.startSubDocument();
-		parseDocument(input, 0, &listener);
+		parseDocument(input, nullptr, &listener);
 		listener.endSubDocument();
 
-		for (std::vector<WP5SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); ++iterSubDoc)
-			if (*iterSubDoc)
-				delete(*iterSubDoc);
+		for (auto &subDocument : subDocuments)
+			if (subDocument)
+				delete subDocument;
 	}
 	catch (FileException)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: File Exception. Parse terminated prematurely."));
-		for (std::vector<WP5SubDocument *>::iterator iterSubDoc = subDocuments.begin(); iterSubDoc != subDocuments.end(); ++iterSubDoc)
-			if (*iterSubDoc)
-				delete(*iterSubDoc);
+		for (auto &subDocument : subDocuments)
+			if (subDocument)
+				delete subDocument;
 		throw FileException();
 	}
 }
