@@ -26,47 +26,47 @@
 
 #ifndef WP6PREFIXINDICE_H
 #define WP6PREFIXINDICE_H
-#include "WPXStream.h"
-#include "libwpd_types.h"
+
+#include <librevenge-stream/librevenge-stream.h>
 
 class WPXEncryption;
 
 class WP6PrefixIndice
 {
 public:
-	WP6PrefixIndice(WPXInputStream *input, WPXEncryption *encryption, int id);
+	WP6PrefixIndice(librevenge::RVNGInputStream *input, WPXEncryption *encryption, int id);
 	int getID() const
 	{
 		return m_id;
 	}
-	uint8_t getType() const
+	unsigned char getType() const
 	{
 		return m_type;
 	}
-	uint8_t getFlags() const
+	unsigned char getFlags() const
 	{
 		return m_flags;
 	}
-	uint32_t getDataSize() const
+	unsigned getDataSize() const
 	{
 		return m_dataSize;
 	}
-	uint32_t getDataOffset() const
+	unsigned getDataOffset() const
 	{
 		return m_dataOffset;
 	}
 
 protected:
-	void _read(WPXInputStream *input, WPXEncryption *encryption);
+	void _read(librevenge::RVNGInputStream *input, WPXEncryption *encryption);
 
 private:
 	int m_id;
-	uint8_t m_type;
-	uint8_t m_flags;
-	uint16_t m_useCount;
-	uint16_t m_hideCount;
-	uint32_t m_dataSize;
-	uint32_t m_dataOffset;
+	unsigned char m_type;
+	unsigned char m_flags;
+	unsigned short m_useCount;
+	unsigned short m_hideCount;
+	unsigned m_dataSize;
+	unsigned m_dataOffset;
 
 	bool m_hasChildren;
 };
